Native support of Multitouch device on Linux, using libmtdev. — Kivy v1.0.1-dev documentation

# Native support of Multitouch device on Linux, using libmtdev.

Mtdev project is a part of Ubuntu Maverick multitouch architecture. You can read more on http://wiki.ubuntu.com/Multitouch

To configure MTDev, it’s preferable to use probesysfs providers. Check `probesysfs` for more information.

Otherwise, you can put in your configuration

    [input]
    # devicename = hidinput,/dev/input/eventXX
    acert230h = mtdev,/dev/input/event2

Note

You must have read access to the input event.

You have the possibility to use custom range for some X, Y and pressure value. On some drivers, the range reported is invalid. To fix that, you can add one of theses options on the argument line :

- invert_x : 1 to invert X axis
- invert_y : 1 to invert Y axis
- min_position_x : X minimum
- max_position_x : X maximum
- min_position_y : Y minimum
- max_position_y : Y maximum
- min_pressure : pressure minimum
- max_pressure : pressure maximum
- min_touch_major : width shape minimum
- max_touch_major : width shape maximum
- min_touch_minor : width shape minimum
- max_touch_minor : height shape maximum